import java.io.IOException;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.FileSystem;
import org.apache.hadoop.fs.LocalFileSystem;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Job;
import org.apache.hadoop.mapreduce.lib.input.FileInputFormat;
import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;
import org.apache.hadoop.util.GenericOptionsParser;
import org.apache.hadoop.fs.*;


public class WordCount_PubMed {

	public static void main(String[] args) throws IOException, InterruptedException, ClassNotFoundException {
		
		//Step 1. Set configuration
		Configuration conf = new Configuration();
		conf.set("fs.default.name", "hdfs://localhost:9000");
		conf.set("mapred.job.tracker", "localhost:9001");
		
		FileSystem hdfs = FileSystem.get(conf);
		LocalFileSystem local = FileSystem.getLocal(conf);
		System.out.println("Working Directory -> " + hdfs.getWorkingDirectory().toString());
		
		Path inputPath = new Path(hdfs.getWorkingDirectory().toString() + "/input");
		Path outputPath = new Path(hdfs.getWorkingDirectory().toString() + "/output");
		
		Path localPath = new Path(local.getWorkingDirectory().toString() + "/ParsedPubMed");
		System.out.println("Local Directory -> " + localPath.toString());
		
		//copy files to inputPath
		if(hdfs.exists(inputPath)) hdfs.delete(inputPath, true);
		hdfs.copyFromLocalFile(false, false, localPath, inputPath);

		//Step 2. Create a Job
		Job job = new Job(conf,"jdwang ParsedPubMed WordsCount(Title)");
		job.setJarByClass(WordCount_PubMed.class);
		
		//Step 3. Set Input format
		//job.setInputFormatClass(WholeFileInputFormat.class);
		
		//Step 4. Set Mapper		
		job.setMapperClass(Mapper_CountTitle.class);		
		
		job.setMapOutputKeyClass(Text.class);
		//job.setMapOutputValueClass(Text.class);
		job.setMapOutputValueClass(IntWritable.class);
		
		//Step 4.1 Set Combiner (Local Reducer)
		//job.setCombinerClass(FileComparatorReducer.class);
		
		//Step 5. Set Reducer
		job.setReducerClass(Reducer_jdwang.class);
		
		//Step 6. Set Input		
		FileInputFormat.addInputPath(job, inputPath);
		
		//Step 7. Set Output
		job.setOutputKeyClass(Text.class);
		job.setOutputValueClass(Text.class);
		
		if(hdfs.exists(outputPath)) hdfs.delete(outputPath, true);
		FileOutputFormat.setOutputPath(job, outputPath);
		
		//Step 8. Submit Job
		job.submit();		
		if(job.waitForCompletion(true)) {
			System.out.println("Job Done!");
			System.exit(0);
		} else {
			System.out.println("Job Failed!");
			System.exit(1);
		}
	} // end of public static void main(String[] args)
} // end of public class WordCount_PubMed
